@@ -1,13 +1,13 @@
 from Functionals import mapFunc
 
-out = lambda *xs: pass
+out = lambda *xs: None
 
 class Pipable():
 	def __init__(self, *val):
 		self.__vals = val
 		self.__arg_count = 1
 	
-	def setvals(self, *vals, /, force=False):
+	def setvals(self, *vals, force=False):
 		if self.__arg_count != len(vals):
 			if force:
 				self.__arg_count = len(vals)
